==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/languages/messages/MessagesRuq_cyrl.php <==
<?php
/** Megleno-Romanian (Cyrillic) (Vlăheşte (Cyrillic))
 *
 * @addtogroup Language
 *
 * @author Макѕе
 * @author Кумулај Маркус
 * @author Siebrand
 */

$fallback = 'mk';

$messages = array(
# User preference toggles
'tog-underline' => 'Сублиниаере легајтулс:',

# Dates
'sun'           => 'Дум',
'mon'           => 'Лун',
'tue'           => 'Мар',
'wed'           => 'Мие',
'thu'           => 'Јои',
'fri'           => 'Вин',
'sat'           => 'Сам',
'january'       => 'јануари',
'february'      => 'февруари',
'march'         => 'марти',
'april'         => 'априли',
'may_long'      => 'мај',
'june'          => 'јуни',
'july'          => 'јули',
'august'        => 'аугуст',
'september'     => 'септември',
'october'       => 'октомври',
'november'      => 'нојември',
'december'      => 'децембри',
'january-gen'   => 'јануари',
'february-gen'  => 'февруари',
'march-gen'     => 'марти',
'april-gen'     => 'априли',
'may-gen'       => 'мај',
'june-gen'      => 'јуни',
'july-gen'      => 'јули',
'august-gen'    => 'аугуст',
'september-gen' => 'септември',
'october-gen'   => 'октомври',
'november-gen'  => 'нојември',
'december-gen'  => 'децември',
'jan'           => 'јан',
'feb'           => 'фев',
'mar'           => 'мар',
'apr'           => 'апр',
'may'           => 'мај',
'jun'           => 'јун',
'jul'           => 'јул',
'aug'           => 'ауг',
'sep'           => 'сеп',
'oct'           => 'окт',
'nov'           => 'нов',
'dec'           => 'дец',

# Bits of text used by many pages
'category_header' => 'Пажус ен категориа "$1"',
'subcategories'   => 'Субкатегории',

'about'  => 'Дајпул',
'cancel' => 'ренунтаје',
'mytalk' => 'Мај дискућу',

'errorpagetitle'   => 'Еру',
'tagline'          => 'Де {{SITENAME}}',
'help'             => 'ајутор',
'search'           => 'каутај',
'searchbutton'     => 'каутај',
'searcharticle'    => 'Лие',
'history'          => 'Хисториа пажус',
'printableversion' => 'верцион принтаблу',
'permalink'        => 'Легајтул перманентул',
'edit'             => 'Едита',
'editthispage'     => 'Едита це пажу',
'delete'           => 'Делајре',
'protect'          => 'Ажатме',
'newpage'          => 'Пажи нови',
'talkpagelinktext' => 'дискућу',
'personaltools'    => 'Алатки персоналу',
'talk'             => 'дискућу',
'views'            => 'Ви',
'toolbox'          => 'алатуникул',
'jumpto'           => 'Лиа а:',
'jumptonavigation' => 'навигацион',
'jumptosearch'     => 'каутај',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'         => 'дајпул {{SITENAME}}',
'aboutpage'         => 'Project:дајпул {{SITENAME}}',
'copyrightpage'     => '{{ns:project}}:Права даутору',
'currentevents'     => 'Тебикору',
'currentevents-url' => 'Project:Тебикору',
'disclaimers'       => 'Тајменулс',
'disclaimerpage'    => 'Project:тајменул',
'edithelp'          => 'Ајутор пентре едитаере',
'edithelppage'      => 'Help:Едитаере',
'helppage'          => 'Help:Ајутор',
'mainpage'          => 'Пажу принципу',
'privacy'           => 'Политикмус де лижитул',
'privacypage'       => 'Project:политикмус де лижитул',
'sitesupport'       => 'Донационс',
'sitesupport-url'   => 'Project:Донаћи',

'retrievedfrom'      => 'адусе де "$1"',
'youhavenewmessages' => 'Весес $1 ($2).',
'newmessageslink'    => 'Месагес новес',
'editsection'        => 'едитаере',
'editold'            => 'едита',
'editsectionhint'    => 'Едитаере ћисецион: $1',
'toc'                => 'Купринс',
'showtoc'            => 'аратај',
'hidetoc'            => 'аскунде',
'site-rss-feed'      => '$1 RSS фитул',
'site-atom-feed'     => '$1 Atom фитул',
'page-rss-feed'      => '"$1" RSS Фитул',
'page-atom-feed'     => '"$1" Atom Фитул',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user'     => 'Пажу дутилизатору',
'nstab-project'  => 'Пројекту',
'nstab-image'    => 'фиширул',
'nstab-category' => 'категориа',

# General errors
'viewsource'    => 'баганаере',
'viewsourcefor' => 'пентру $1',

# Login and logout pages
'yourname'   => 'Ном дутилизатору:',
'login'      => 'Приласнаере',
'userlogin'  => 'Приласнаере / креаре нутилизатору',
'userlogout' => 'отластаере',

# Edit page toolbar
'bold_sample'     => 'Ескрире алдин',
'bold_tip'        => 'Ескрире алдин',
'italic_sample'   => 'Ескрире курсиве',
'italic_tip'      => 'Ескрире курсиве',
'link_sample'     => 'Ном с-легајтулс',
'link_tip'        => 'Легајтул интернул',
'extlink_sample'  => 'http://www.example.com ном с-легајтулс',
'extlink_tip'     => 'Легајтул ќстернул (вец префикс http://)',
'headline_sample' => 'Ескрире с-титлус',
'headline_tip'    => 'Титлу де нивел 2',
'math_sample'     => 'Интродуца формула иси',
'math_tip'        => 'Формула с-математикс (LaTeX)',
'nowiki_sample'   => 'Интродуца но-Вики иси',
'nowiki_tip'      => 'Но-Бики клашу',
'image_tip'       => 'Сантигул',
'media_tip'       => 'Легајтул фиширул де медиа',
'sig_tip'         => 'Утилизаторуном ет дата ет темп',
'hr_tip'          => 'Линеа оризонтала (еснидивале)',

# Edit pages
'summary'                => 'Сумар',
'watchthis'              => 'Клајаере це пажу',
'showdiff'               => 'Аратај шумбајрае',
'newarticle'             => '(Нова)',
'editing'                => 'о $1 едитаере',
'editingsection'         => 'Едитаере $1 (секцион)',
'template-protected'     => '(ажатмат)',
'template-semiprotected' => '(семи-ажатмат)',

# History pages
'currentrev'   => 'Верцион куренту',
'revisionasof' => 'Верцион де дата $1',
'cur'          => 'актуалу',
'last'         => 'прецеденте',

# Diffs
'history-title'           => 'Едитаерехисториа пентру "$1"',
'lineno'                  => 'линиа $1:',
'compareselectedversions' => 'Компара верционс селектус',
'editundo'                => 'анулизаје',

# Search results
'noexactmatch' => "'''Нпажу вец лном \"\$1\" н-ќсистст.''' Путе [[:\$1|креаре це пажу]].",
'viewprevnext' => 'Ву ($1) ($2) ($3)',
'powersearch'  => 'каутај',

# Preferences page
'mypreferences' => 'Мај префиренћу',

# Recent changes
'recentchanges'   => 'шумбајрае рецентае',
'rcshowhidebots'  => '$1 роботи',
'rcshowhideliu'   => '$1 утилизатори приласнаери',
'rcshowhideanons' => '$1 утилизатори аноними',
'rcshowhidemine'  => '$1 мес модификационс',
'diff'            => 'диференћу',
'hist'            => 'хисториа',
'hide'            => 'аскунде',
'show'            => 'Аратај',
'minoreditletter' => 'м',
'newpageletter'   => 'Н',
'boteditletter'   => 'б',

# Upload
'upload' => 'тримиће фиширул',

# Image list
'filehist'            => 'Хисториа фиширулу',
'filehist-current'    => 'куренту',
'filehist-datetime'   => 'Дата/Темп',
'filehist-user'       => 'Утилизатору',
'filehist-dimensions' => 'Дименционс',
'filehist-comment'    => 'коментарул',
'imagelinks'          => 'легајтул',
'linkstoimage'        => 'Цес пажи легајтент а це фиширул:',

# Random page
'randompage' => 'алаећу',

# Miscellaneous special pages
'nbytes'       => '$1 {{PLURAL:$1|бајтул|бајтулс}}',
'nmembers'     => '$1 {{PLURAL:$1|мембру|мембри}}',
'allpages'     => 'Тоатс пажи',
'specialpages' => 'Пажи спецалус',
'newpages'     => 'Пажи нови',

'alphaindexline' => '$1 во $2',

# Special:Allpages
'allarticles'    => 'Тоат пажи',
'allpagessubmit' => 'Треме',

# Watchlist
'watchlist'    => 'Мај клајаеру',
'mywatchlist'  => 'Мај клајаере',
'watchlistfor' => "(пентру '''$1''')",
'watch'        => 'клајаере',
'unwatch'      => 'Деклајаера',

# Displayed when you click the "watch" button and it's in the process of watching
'watching'   => 'О клајаере...',
'unwatching' => 'О деклајаере...',

# Delete/protect/revert
'deletedarticle' => 'делајрај "[[$1]]"',
'rollbacklink'   => 'ревенире',

# Namespace form on various pages
'invert'         => 'Ќсклуда спаћул',
'blanknamespace' => '(Принципу)',

# Contributions
'contributions' => 'Контрибући дутилизатори',
'mycontris'     => 'Мес контрибући',
'contribsub2'   => 'пентру $1 ($2)',
'uctop'         => '(сусверф)',

# What links here
'whatlinkshere'       => 'Легајтул а це пажу',
'whatlinkshere-title' => 'Пажус легајтулент а $1',
'linklistsub'         => '(Листа де легајтул)',
'nolinkshere'         => "Пажи не легајтент а '''[[:$1]]'''.",
'istemplate'          => 'викулабе',
'whatlinkshere-links' => '← легајтулс',

# Block/unblock
'blocklink'    => 'блокуапаје',
'contribslink' => 'контрибући',

# Move page
'revertmove' => 'ревенире',

# Export
'export' => 'Ќспорта пажи',

# Thumbnails
'thumbnail-more'  => 'ќсинде',
'thumbnail_error' => 'Еру вец лкреаре де тумбнел: $1',

# Tooltip help for the actions
'tooltip-pt-userpage'       => 'Мој пажу дутилизатору',
'tooltip-pt-mytalk'         => 'Мај пажу дискућус',
'tooltip-pt-preferences'    => 'Мај префиренћу',
'tooltip-pt-mycontris'      => 'Листа де мес контрибуционс',
'tooltip-pt-login'          => 'Путе приласнаере, не лест доист.',
'tooltip-pt-logout'         => 'отластаере',
'tooltip-ca-protect'        => 'Ажатме це пажу',
'tooltip-ca-delete'         => 'Делајре це пажу',
'tooltip-search'            => 'Каутај ен {{SITENAME}}',
'tooltip-n-mainpage'        => 'Вижита лпажу принципу',
'tooltip-n-portal'          => 'Дајпул лпројецту, љуелљуес путе фараере, о трувес саби.',
'tooltip-n-recentchanges'   => 'Листа дес шумбајрае рецентае ен лБики.',
'tooltip-n-help'            => 'Ајутор трувес иси.',
'tooltip-n-sitesupport'     => 'Супора-ностре',
'tooltip-t-contributions'   => 'Ву листа де контрибући де цутилизатору',
'tooltip-t-specialpages'    => 'Листа де тоат пажи специалус',
'tooltip-ca-nstab-user'     => 'Ву лпажу дутилизатору',
'tooltip-ca-nstab-project'  => 'Ву лпажу де пројекту',
'tooltip-ca-nstab-category' => 'Ву лпажу де категориа',
'tooltip-minoredit'         => 'Це-ест нмодификацион минару',
'tooltip-save'              => 'Салваере тес модификационс',

# Spam protection
'listingcontinuesabbrev' => 'контину',

# Media information
'file-nohires'   => '<small>Це-н-ест нресолуцион маи мари.</small>',
'show-big-image' => 'Мареште ресолуцион',

# Metadata
'metadata' => 'Метадата',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'тоат',
'namespacesall' => 'тоат',
'monthsall'     => 'тоат',

);

==> mediawiki-1.15.2.tar.gz: mediawiki-1.15.2/languages/messages/MessagesRuq_cyrl.php <==
<?php
/** Megleno-Romanian (Cyrillic) (Vlăheşte (Cyrillic))
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Кумулај Маркус
 * @author Макѕе
 * @author Приетен тев
 */

$fallback = 'mk';

$messages = array(
# User preference toggles
'tog-underline' => 'Сублиниаере легајтулс:',

# Dates
'sun'           => 'Дум',
'mon'           => 'Лун',
'tue'           => 'Мар',
'wed'           => 'Мие',
'thu'           => 'Јои',
'fri'           => 'Вин',
'sat'           => 'Сам',
'january'       => 'јануари',
'february'      => 'февруари',
'march'         => 'марти',
'april'         => 'априли',
'may_long'      => 'мај',
'june'          => 'јуни',
'july'          => 'јули',
'august'        => 'аугуст',
'september'     => 'септември',
'october'       => 'октомври',
'november'      => 'нојември',
'december'      => 'децембри',
'january-gen'   => 'јануари',
'february-gen'  => 'февруари',
'march-gen'     => 'марти',
'april-gen'     => 'априли',
'may-gen'       => 'мај',
'june-gen'      => 'јуни',
'july-gen'      => 'јули',
'august-gen'    => 'аугуст',
'september-gen' => 'септември',
'october-gen'   => 'октомври',
'november-gen'  => 'нојември',
'december-gen'  => 'децември',
'jan'           => 'јан',
'feb'           => 'фев',
'mar'           => 'мар',
'apr'           => 'апр',
'may'           => 'мај',
'jun'           => 'јун',
'jul'           => 'јул',
'aug'           => 'ауг',
'sep'           => 'сеп',
'oct'           => 'окт',
'nov'           => 'нов',
'dec'           => 'дец',

# Categories related messages
'category_header'        => 'Пажус ен категориа "$1"',
'subcategories'          => 'Субкатегории',
'listingcontinuesabbrev' => 'контину',

'about'  => 'Дајпул',
'cancel' => 'ренунтаје',
'mytalk' => 'Мај дискућу',

'errorpagetitle'   => 'Еру',
'tagline'          => 'Де {{SITENAME}}',
'help'             => 'ајутор',
'search'           => 'каутај',
'searchbutton'     => 'каутај',
'searcharticle'    => 'Лие',
'history'          => 'Хисториа пажус',
'printableversion' => 'верцион принтаблу',
'permalink'        => 'Легајтул перманентул',
'edit'             => 'Едита',
'editthispage'     => 'Едита це пажу',
'delete'           => 'Делајре',
'protect'          => 'Ажатме',
'newpage'          => 'Пажи нови',
'talkpagelinktext' => 'дискућу',
'personaltools'    => 'Алатки персоналу',
'talk'             => 'дискућу',
'views'            => 'Ви',
'toolbox'          => 'алатуникул',
'redirectedfrom'   => '(Редирецћионат де ла $1)',
'jumpto'           => 'Лиа а:',
'jumptonavigation' => 'навигацион',
'jumptosearch'     => 'каутај',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'дајпул {{SITENAME}}',
'aboutpage'            => 'Project:дајпул {{SITENAME}}',
'copyrightpage'        => '{{ns:project}}:Права даутору',
'currentevents'        => 'Тебикору',
'currentevents-url'    => 'Project:Тебикору',
'disclaimers'          => 'Тајменулс',
'disclaimerpage'       => 'Project:тајменул',
'edithelp'             => 'Ајутор пентре едитаере',
'edithelppage'         => 'Help:Едитаере',
'helppage'             => 'Help:Ајутор',
'mainpage'             => 'Пажу принципу',
'mainpage-description' => 'Пажу принципу',
'privacy'              => 'Политикмус де лижитул',
'privacypage'          => 'Project:политикмус де лижитул',

'retrievedfrom'      => 'адусе де "$1"',
'youhavenewmessages' => 'Весес $1 ($2).',
'newmessageslink'    => 'Месагес новес',
'editsection'        => 'едитаере',
'editold'            => 'едита',
'editsectionhint'    => 'Едитаере ћисецион: $1',
'toc'                => 'Купринс',
'showtoc'            => 'аратај',
'hidetoc'            => 'аскунде',
'site-rss-feed'      => '$1 RSS фитул',
'site-atom-feed'     => '$1 Atom фитул',
'page-rss-feed'      => '"$1" RSS Фитул',
'page-atom-feed'     => '"$1" Atom Фитул',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user'     => 'Пажу дутилизатору',
'nstab-project'  => 'Пројекту',
'nstab-image'    => 'фиширул',
'nstab-category' => 'категориа',

# General errors
'viewsource'    => 'баганаере',
'viewsourcefor' => 'пентру $1',

# Login and logout pages
'yourname'                => 'Ном дутилизатору:',
'login'                   => 'Приласнаере',
'nav-login-createaccount' => 'Приласнаере / Нажбе',
'userlogin'               => 'Приласнаере / креаре нутилизатору',
'userlogout'              => 'отластаере',

# Edit page toolbar
'bold_sample'     => 'Ескрире алдин',
'bold_tip'        => 'Ескрире алдин',
'italic_sample'   => 'Ескрире курсиве',
'italic_tip'      => 'Ескрире курсиве',
'link_sample'     => 'Ном с-легајтулс',
'link_tip'        => 'Легајтул интернул',
'extlink_sample'  => 'http://www.example.com ном с-легајтулс',
'extlink_tip'     => 'Легајтул ќстернул (вец префикс http://)',
'headline_sample' => 'Ескрире с-титлус',
'headline_tip'    => 'Титлу де нивел 2',
'math_sample'     => 'Интродуца формула иси',
'math_tip'        => 'Формула с-математикс (LaTeX)',
'nowiki_sample'   => 'Интродуца но-Вики иси',
'nowiki_tip'      => 'Но-Бики клашу',
'image_tip'       => 'Сантигул инсерат',
'media_tip'       => 'Легајтул фиширул де медиа',
'sig_tip'         => 'Утилизаторуном ет дата ет темп',
'hr_tip'          => 'Линеа оризонтала (еснидивале)',

# Edit pages
'summary'                => 'Сумар:',
'subject'                => 'Субјект / титлур:',
'minoredit'              => 'Ацеаста есте о едитаре минорај',
'watchthis'              => 'Клајаере це пажу',
'showpreview'            => 'Ратај превизуализаре',
'showdiff'               => 'Аратај шумбајрае',
'newarticle'             => '(Нова)',
'editing'                => 'о $1 едитаере',
'editingsection'         => 'Едитаере $1 (секцион)',
'copyrightwarning'       => "<!-- Гол деоцамдатај. Вертисментул се флај ен MediaWiki:Summary -->
Те рог нотари ла дин контрибући ал {{SITENAME}} сунт консидераере релесават супра $2 (суах $1 дин детајс). Аџтеу несав те се тексти сунт едитаере деномерци дет редистрибутаере дин вент, хатае ици.<br /> Ту есте ностре промисаере бонти ус ту скрирсте це се, нега копиаере дин публик домен нега симилари ресорсуе. '''НЕ СУБМИТЕ КОПИЛЕГРУ СКРИЕ САС ПЕРМИћИОН!'''",
'template-protected'     => '(ажатмат)',
'template-semiprotected' => '(семи-ажатмат)',

# History pages
'currentrev'       => 'Верцион куренту',
'revisionasof'     => 'Верцион де дата $1',
'previousrevision' => '←Версиунеа нтериоарај',
'cur'              => 'актуалу',
'last'             => 'прецеденте',

# Diffs
'history-title'           => 'Едитаерехисториа пентру "$1"',
'lineno'                  => 'линиа $1:',
'compareselectedversions' => 'Компара верционс селектус',
'editundo'                => 'анулизаје',

# Search results
'noexactmatch'   => "'''Нпажу вец лном \"\$1\" н-ќсистст.''' Путе [[:\$1|креаре це пажу]].",
'viewprevnext'   => 'Ву ($1 {{int:pipe-separator}} $2) ($3)',
'searchhelp-url' => 'Help:Ајутор',
'powersearch'    => 'каутај авансата',

# Preferences page
'mypreferences' => 'Мај префиренћу',

# Recent changes
'recentchanges'   => 'шумбајрае рецентае',
'rcnote'          => "Маи хос се флај {{PLURAL:$|ултима модификаре|ултимеле '''$1''' модификајри}} дин {{PLURAL:$2|ултима зи|ултимеле '''$2''' зиле}}, енцепонд цу $3.",
'rcshowhideminor' => '$1 модификајриле миноре',
'rcshowhidebots'  => '$1 роботи',
'rcshowhideliu'   => '$1 утилизатори приласнаери',
'rcshowhideanons' => '$1 утилизатори аноними',
'rcshowhidemine'  => '$1 мес модификационс',
'rclinks'         => 'Ратај ултимеле $1 модификајри дин ултимеле $2 зиле.<br />
$3',
'diff'            => 'диференћу',
'hist'            => 'хисториа',
'hide'            => 'аскунде',
'show'            => 'Аратај',
'minoreditletter' => 'м',
'newpageletter'   => 'Н',
'boteditletter'   => 'б',

# Recent changes linked
'recentchangeslinked' => 'Модификајри корелате',

# Upload
'upload' => 'тримиће фиширул',

# File description page
'filehist'            => 'Хисториа фиширулу',
'filehist-current'    => 'куренту',
'filehist-datetime'   => 'Дата/Темп',
'filehist-user'       => 'Утилизатору',
'filehist-dimensions' => 'Дименционс',
'filehist-comment'    => 'коментарул',
'imagelinks'          => 'легајтул',
'linkstoimage'        => 'Цес пажи легајтент а це фиширул:',

# Random page
'randompage' => 'алаећу',

# Miscellaneous special pages
'nbytes'   => '$1 {{PLURAL:$1|бајтул|бајтулс}}',
'nmembers' => '$1 {{PLURAL:$1|мембру|мембри}}',
'newpages' => 'Пажи нови',

# Book sources
'booksources' => 'Сурсе де цајрћи',

# Special:AllPages
'allpages'       => 'Тоатс пажи',
'alphaindexline' => '$1 во $2',
'allarticles'    => 'Тоат пажи',
'allpagessubmit' => 'Треме',

# Watchlist
'watchlist'    => 'Мај клајаеру',
'mywatchlist'  => 'Мај клајаере',
'watchlistfor' => "(пентру '''$1''')",
'watch'        => 'клајаере',
'unwatch'      => 'Деклајаера',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'О клајаере...',
'unwatching' => 'О деклајаере...',

# Delete
'deletedarticle' => 'делајрај "[[$1]]"',

# Rollback
'rollbacklink' => 'ревенире',

# Namespace form on various pages
'namespace'      => 'лСпаћи:',
'invert'         => 'Ќсклуда спаћул',
'blanknamespace' => '(Принципу)',

# Contributions
'contributions' => 'Контрибући дутилизатори',
'mycontris'     => 'Мес контрибући',
'contribsub2'   => 'пентру $1 ($2)',
'uctop'         => '(сусверф)',

# What links here
'whatlinkshere'       => 'Легајтул а це пажу',
'whatlinkshere-title' => 'Пажус легајтулент а $1',
'nolinkshere'         => "Пажи не легајтент а '''[[:$1]]'''.",
'istemplate'          => 'викулабе',
'whatlinkshere-links' => '← легајтулс',

# Block/unblock
'blocklink'    => 'блокуапаје',
'contribslink' => 'контрибући',

# Move page
'revertmove' => 'ревенире',

# Export
'export' => 'Ќспорта пажи',

# Thumbnails
'thumbnail-more'  => 'ќсинде',
'thumbnail_error' => 'Еру вец лкреаре де тумбнел: $1',

# Tooltip help for the actions
'tooltip-pt-userpage'       => 'Мој пажу дутилизатору',
'tooltip-pt-mytalk'         => 'Мај пажу дискућус',
'tooltip-pt-preferences'    => 'Мај префиренћу',
'tooltip-pt-watchlist'      => 'Листа пажинилор пе царе ле мониторизез.',
'tooltip-pt-mycontris'      => 'Листа де мес контрибуционс',
'tooltip-pt-login'          => 'Путе приласнаере, не лест доист.',
'tooltip-pt-logout'         => 'отластаере',
'tooltip-ca-talk'           => 'Дискућие деспре артикол',
'tooltip-ca-edit'           => 'Поћи едита ацеатај пажинај. Те ругајм се превизуализези конћинутул енаинте де салваре.',
'tooltip-ca-protect'        => 'Ажатме це пажу',
'tooltip-ca-delete'         => 'Делајре це пажу',
'tooltip-search'            => 'Каутај ен {{SITENAME}}',
'tooltip-n-mainpage'        => 'Вижита лпажу принципу',
'tooltip-n-portal'          => 'Дајпул лпројецту, љуелљуес путе фараере, о трувес саби.',
'tooltip-n-currentevents'   => 'Гајсеште информаћии деспре евениментиќ куренте',
'tooltip-n-recentchanges'   => 'Листа дес шумбајрае рецентае ен лБики.',
'tooltip-n-randompage'      => 'Донаре нпажу алаетоаре',
'tooltip-n-help'            => 'Ајутор трувес иси.',
'tooltip-t-whatlinkshere'   => 'Листа тутурор пажинилор вики царе кондуц спре ацестај пажинај',
'tooltip-t-contributions'   => 'Ву листа де контрибући де цутилизатору',
'tooltip-t-upload'          => 'Тремер фиширул',
'tooltip-t-specialpages'    => 'Листа де тоат пажи специалус',
'tooltip-ca-nstab-user'     => 'Ву лпажу дутилизатору',
'tooltip-ca-nstab-project'  => 'Ву лпажу де пројекту',
'tooltip-ca-nstab-category' => 'Ву лпажу де категориа',
'tooltip-minoredit'         => 'Це-ест нмодификацион минару',
'tooltip-save'              => 'Салваере тес модификационс',
'tooltip-diff'              => 'Ратај це модификајри аи фајцут текстулуи.',

# Media information
'file-nohires'   => '<small>Це-н-ест нресолуцион маи мари.</small>',
'show-big-image' => 'Мареште ресолуцион',

# Bad image list
'bad_image_list' => 'Форматул есте урмајторул:

Нумај елементијле унеи листе сунт луате ен цонсидераере. (Аџестеа сунт линии це енцеп цу *)

Прима легајтурај де пе линие требуие се фие спре ун фишиер дефецтуос.

Орице легајтури це урмеазај пе аценаши линие сунт цонсидераете еџцепћии, дицај пажи унде фишиерул поате пајреа инцлус дирецт.',

# Metadata
'metadata' => 'Метадата',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'тоат',
'namespacesall' => 'тоат',
'monthsall'     => 'тоат',

# Special:SpecialPages
'specialpages' => 'Пажи спецалус',

);
